pub enum ResolutionSearchMode {
MinDiff,
SmallerThanPixel,
}Variants
MinDiff
Chose the h3 resolution where the difference in the area of a pixel and the h3index is as small as possible.
SmallerThanPixel
Chose the h3 resolution where the area of the h3index is smaller than the area of a pixel.