pub fn nearest_h3_resolution(
shape: &[usize],
transform: &Transform,
axis_order: &AxisOrder,
search_mode: ResolutionSearchMode,
) -> Result<u8, Error>Expand description
Find the h3 resolution closed to the size of a pixel in an array of the given shape with the given transform.